@@ -15,9 +15,7 @@
 
 // Frameworks
 #include <KConfigGroup>
-#include <KDeclarative/KDeclarative>
 #include <KLocalizedString>
-#include <KPackage/PackageLoader>
 #include <Plasma/Theme>
 
 // Own
@@ -90,19 +88,9 @@ int main(int argc, char **argv)
 
     QQmlApplicationEngine engine;
 
-    KDeclarative::KDeclarative kdeclarative;
-    kdeclarative.setDeclarativeEngine(&engine);
-    kdeclarative.setTranslationDomain(QStringLiteral("cuttlefish"));
-    kdeclarative.setupContext();
-    kdeclarative.setupEngine(&engine);
-
-    auto package = KPackage::PackageLoader::self()->loadPackage("Plasma/Generic");
-    package.setPath("org.kde.plasma.cuttlefish");
-
-    if (!package.isValid() || !package.metadata().isValid()) {
-        qWarning() << "Could not load package org.kde.plasma.cuttlefish:" << package.path();
-        return -1;
-    }
+    auto l10nContext = new KLocalizedContext(&engine);
+    l10nContext->setTranslationDomain(QStringLiteral("cuttlefish"));
+    engine.rootContext()->setContextObject(l10nContext);
 
     auto iconModel = new CuttleFish::IconModel(engine.rootContext());
     auto proxyModel = new CuttleFish::SortFilterModel(engine.rootContext());
@@ -115,7 +103,7 @@ int main(int argc, char **argv)
     engine.rootContext()->setContextProperty("pickerMode", parser.isSet("picker"));
     engine.rootContext()->setContextProperty("colorSchemes", colorSchemes);
 
-    engine.load(QUrl::fromLocalFile(package.filePath("mainscript")));
+    engine.load(QUrl("qrc:/qml/cuttlefish.qml"));
     if (engine.rootObjects().isEmpty()) {
         return -1;
     }
